@@ -1,6 +1,15 @@
 # Copyright (c) 2006-2015 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2010 Julien Jehannet <julien.jehannet@logilab.fr>
 # Copyright (c) 2013-2014 Google, Inc.
-# Copyright (c) 2014-2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014-2018 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014 Brett Cannon <brett@python.org>
+# Copyright (c) 2014 Ricardo Gemignani <ricardo.gemignani@gmail.com>
+# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2016 Moises Lopez <moylop260@vauxoo.com>
+# Copyright (c) 2016 Florian Bruhin <git@the-compiler.org>
+# Copyright (c) 2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright (c) 2017 Hugo <hugovk@users.noreply.github.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -18,20 +27,17 @@ from setuptools import __version__ as setuptools_version
 
 modname = distname = 'pylint'
 
-numversion = (2, 0, 0)
+numversion = (1, 9, 2)
 version = '.'.join([str(num) for num in numversion])
 
 install_requires = [
-    'astroid',
+    'astroid>=1.6,<2.0',
     'six',
     'isort >= 4.2.5',
     'mccabe',
-    'editdistance',
 ]
 
-dependency_links = [
-    'https://github.com/PyCQA/astroid/tarball/master#egg=astroid-master-1.5'
-]
+dependency_links = []
 
 extras_require = {}
 extras_require[':sys_platform=="win32"'] = ['colorama']
@@ -70,7 +76,13 @@ classifiers = ['Development Status :: 4 - Beta',
                'Operating System :: OS Independent',
                'Programming Language :: Python',
                'Programming Language :: Python :: 2',
+               'Programming Language :: Python :: 2.7',
                'Programming Language :: Python :: 3',
+               'Programming Language :: Python :: 3.4',
+               'Programming Language :: Python :: 3.5',
+               'Programming Language :: Python :: 3.6',
+               'Programming Language :: Python :: Implementation :: CPython',
+               'Programming Language :: Python :: Implementation :: PyPy',
                'Topic :: Software Development :: Debuggers',
                'Topic :: Software Development :: Quality Assurance',
                'Topic :: Software Development :: Testing'
