@@ -3,9 +3,9 @@
 # Copyright (c) 2016-2017 Łukasz Rogalski <rogalski.91@gmail.com>
 # Copyright (c) 2016 Moises Lopez <moylop260@vauxoo.com>
 # Copyright (c) 2016 Alexander Todorov <atodorov@otb.bg>
+# Copyright (c) 2017-2018 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2017 Hugo <hugovk@users.noreply.github.com>
 # Copyright (c) 2017 Bryce Guinta <bryce.paul.guinta@gmail.com>
-# Copyright (c) 2017 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2017 Łukasz Sznuk <ls@rdprojekt.pl>
 # Copyright (c) 2017 Alex Hearn <alex.d.hearn@gmail.com>
 # Copyright (c) 2017 Antonio Ossa <aaossa@uc.cl>
@@ -568,6 +568,11 @@ class RefactoringChecker(checkers.BaseTokenChecker):
             if not node.exc:
                 # Ignore bare raises
                 return True
+            if not utils.is_node_inside_try_except(node):
+                # If the raise statement is not inside a try/except statement
+                # then the exception is raised and cannot be caught. No need
+                # to infer it.
+                return True
             exc = utils.safe_infer(node.exc)
             if exc is None or exc is astroid.Uninferable:
                 return False
@@ -583,7 +588,9 @@ class RefactoringChecker(checkers.BaseTokenChecker):
         if isinstance(node, astroid.If):
             # if statement is returning if there are exactly two return statements in its
             # children : one for the body part, the other for the orelse part
-            return_stmts = [self._is_node_return_ended(_child) for _child in node.get_children()]
+            # Do not check if inner function definition are return ended.
+            return_stmts = [self._is_node_return_ended(_child) for _child in node.get_children()
+                            if not isinstance(_child, astroid.FunctionDef)]
             return sum(return_stmts) == 2
         # recurses on the children of the node except for those which are except handler
         # because one cannot be sure that the handler will really be used
