@@ -1,17 +1,29 @@
-# Copyright (c) 2009-2010 Arista Networks, Inc. - James Lingard
-# Copyright (c) 2004-2016 LOGILAB S.A. (Paris, FRANCE).
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
+# -*- coding: utf-8 -*-
+# Copyright (c) 2009 Charles Hebert <charles.hebert@logilab.fr>
+# Copyright (c) 2010-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2010 Daniel Harding <dharding@gmail.com>
+# Copyright (c) 2012-2014 Google, Inc.
+# Copyright (c) 2013-2017 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014 Brett Cannon <brett@python.org>
+# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
+# Copyright (c) 2015 Rene Zhang <rz99@cornell.edu>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2016 Peter Dawyndt <Peter.Dawyndt@UGent.be>
+# Copyright (c) 2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
+# Copyright (c) 2017 Ville Skyttä <ville.skytta@iki.fi>
+
+
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
 
 """Checker for string formatting operations.
 """
 
-import numbers
+import sys
 import tokenize
 import string
-import sys
+import numbers
 
 import six
 
@@ -88,7 +100,7 @@ MSGS = {
     'W1305': ("Format string contains both automatic field numbering "
               "and manual field specification",
               "format-combined-specification",
-              "Usen when a PEP 3101 format string contains both automatic "
+              "Used when a PEP 3101 format string contains both automatic "
               "field numbering (e.g. '{}') and manual field "
               "specification (e.g. '{0}').",
               {'minversion': (2, 7)}),
@@ -124,7 +136,10 @@ else:
                 yield is_attr, key
 
     def split_format_field_names(format_string):
-        keyname, fielditerator = format_string._formatter_field_name_split()
+        try:
+            keyname, fielditerator = format_string._formatter_field_name_split()
+        except ValueError:
+            raise utils.IncompleteFormatString
         # it will return longs, instead of ints, which will complicate
         # the output
         return keyname, _field_iterator_convertor(fielditerator)
@@ -184,24 +199,27 @@ def parse_format_method_string(format_string):
                 # to different output between 2 and 3
                 manual_pos_arg.add(str(keyname))
                 keyname = int(keyname)
-            keys.append((keyname, list(fielditerator)))
+            try:
+                keys.append((keyname, list(fielditerator)))
+            except ValueError:
+                raise utils.IncompleteFormatString()
         else:
             num_args += 1
     return keys, num_args, len(manual_pos_arg)
 
-def get_args(callfunc):
-    """Get the arguments from the given `CallFunc` node.
+def get_args(call):
+    """Get the arguments from the given `Call` node.
 
     Return a tuple, where the first element is the
     number of positional arguments and the second element
     is the keyword arguments in a dict.
     """
-    if callfunc.keywords:
+    if call.keywords:
         named = {arg.arg: utils.safe_infer(arg.value)
-                 for arg in callfunc.keywords}
+                 for arg in call.keywords}
     else:
         named = {}
-    positional = len(callfunc.args)
+    positional = len(call.args)
     return positional, named
 
 def get_access_path(key, parts):
@@ -271,7 +289,7 @@ class StringFormatChecker(BaseChecker):
                     else:
                         # One of the keys was something other than a
                         # constant.  Since we can't tell what it is,
-                        # supress checks for missing keys in the
+                        # suppress checks for missing keys in the
                         # dictionary.
                         unknown_keys = True
                 if not unknown_keys:
@@ -297,7 +315,10 @@ class StringFormatChecker(BaseChecker):
             # the % operator matches the number required by the format
             # string.
             if isinstance(args, astroid.Tuple):
-                num_args = len(args.elts)
+                rhs_tuple = utils.safe_infer(args)
+                num_args = None
+                if rhs_tuple not in (None, astroid.Uninferable):
+                    num_args = len(rhs_tuple.elts)
             elif isinstance(args, OTHER_NODES + (astroid.Dict, astroid.DictComp)):
                 num_args = 1
             else:
@@ -440,7 +461,7 @@ class StringFormatChecker(BaseChecker):
                 argument = next(argname.infer())
             except astroid.InferenceError:
                 continue
-            if not specifiers or argument is astroid.YES:
+            if not specifiers or argument is astroid.Uninferable:
                 # No need to check this key if it doesn't
                 # use attribute / item access
                 continue
@@ -451,7 +472,7 @@ class StringFormatChecker(BaseChecker):
             previous = argument
             parsed = []
             for is_attribute, specifier in specifiers:
-                if previous is astroid.YES:
+                if previous is astroid.Uninferable:
                     break
                 parsed.append((is_attribute, specifier))
                 if is_attribute:
@@ -471,11 +492,15 @@ class StringFormatChecker(BaseChecker):
                     warn_error = False
                     if hasattr(previous, 'getitem'):
                         try:
-                            previous = previous.getitem(specifier)
-                        except (IndexError, TypeError):
+                            previous = previous.getitem(astroid.Const(specifier))
+                        except (astroid.AstroidIndexError,
+                                astroid.AstroidTypeError,
+                                astroid.AttributeInferenceError):
                             warn_error = True
                         except astroid.InferenceError:
                             break
+                        if previous is astroid.Uninferable:
+                            break
                     else:
                         try:
                             # Lookup __getitem__ in the current node,
@@ -499,7 +524,6 @@ class StringFormatChecker(BaseChecker):
                     break
 
 
-
 class StringConstantChecker(BaseTokenChecker):
     """Check string literals"""
     __implements__ = (ITokenChecker, IRawChecker)
