@@ -12,12 +12,14 @@
 # Copyright (c) 2015 Florian Bruhin <me@the-compiler.org>
 # Copyright (c) 2015 Radu Ciorba <radu@devrandom.ro>
 # Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2016, 2018 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2016-2017 Łukasz Rogalski <rogalski.91@gmail.com>
 # Copyright (c) 2016-2017 Moises Lopez <moylop260@vauxoo.com>
-# Copyright (c) 2016 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2016 Brian C. Lane <bcl@redhat.com>
+# Copyright (c) 2017-2018 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2017 ttenhoeve-aa <ttenhoeve@appannie.com>
-# Copyright (c) 2017 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
+# Copyright (c) 2018 Brian Shaginaw <brian.shaginaw@warbyparker.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -596,6 +598,7 @@ def unimplemented_abstract_methods(node, is_abstract_cb=None):
 
 
 def _import_node_context(node):
+    """Return the ExceptHandler or the TryExcept node in which the node is."""
     current = node
     ignores = (astroid.ExceptHandler, astroid.TryExcept)
     while current and not isinstance(current.parent, ignores):
@@ -642,17 +645,27 @@ def get_exception_handlers(node, exception):
         generator: the collection of handlers that are handling the exception or None.
 
     """
-    current = node
-    ignores = (astroid.ExceptHandler, astroid.TryExcept)
-    while current and not isinstance(current.parent, ignores):
-        current = current.parent
-
-    if current and isinstance(current.parent, astroid.TryExcept):
-        return (_handler for _handler in current.parent.handlers
+    context = _import_node_context(node)
+    if isinstance(context, astroid.TryExcept):
+        return (_handler for _handler in context.handlers
                 if error_of_type(_handler, exception))
     return None
 
 
+def is_node_inside_try_except(node):
+    """Check if the node is directly under a Try/Except statement.
+    (but not under an ExceptHandler!)
+
+    Args:
+        node (astroid.Raise): the node raising the exception.
+
+    Returns:
+        bool: True if the node is inside a try/except statement, False otherwise.
+    """
+    context = _import_node_context(node)
+    return isinstance(context, astroid.TryExcept)
+
+
 def node_ignores_exception(node, exception):
     """Check if the node is in a TryExcept which handles the given exception."""
     managing_handlers = get_exception_handlers(node, exception)
@@ -917,3 +930,39 @@ def get_node_last_lineno(node):
         return get_node_last_lineno(node.body[-1])
     # Not a compound statement
     return node.lineno
+
+
+def in_comprehension(node):
+    """Return True if the given node is in a comprehension"""
+    curnode = node
+    while curnode.parent:
+        curnode = curnode.parent
+        if is_comprehension(curnode):
+            return True
+
+    return False
+
+
+def is_enum_class(node):
+    """Check if a class definition defines an Enum class.
+
+    :param node: The class node to check.
+    :type node: astroid.ClassDef
+
+    :returns: True if the given node represents an Enum class. False otherwise.
+    :rtype: bool
+    """
+    for base in node.bases:
+        try:
+            inferred_bases = base.inferred()
+        except astroid.InferenceError:
+            continue
+
+        for ancestor in inferred_bases:
+            if not isinstance(ancestor, astroid.ClassDef):
+                continue
+
+            if ancestor.name == 'Enum' and ancestor.root().name == 'enum':
+                return True
+
+    return False
