@@ -1,22 +1,24 @@
-# Copyright (c) 2003-2016 LOGILAB S.A. (Paris, FRANCE).
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
+# Copyright (c) 2014 Google, Inc.
+# Copyright (c) 2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2015-2018 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
+
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
 
 """Unittest for the logging checker."""
-import unittest
-from astroid import test_utils
+import astroid
 
 from pylint.checkers import logging
-
 from pylint.testutils import CheckerTestCase, Message, set_config
 
 
-class LoggingModuleDetectionTest(CheckerTestCase):
+class TestLoggingModuleDetection(CheckerTestCase):
     CHECKER_CLASS = logging.LoggingChecker
-    
+
     def test_detects_standard_logging_module(self):
-        stmts = test_utils.extract_node("""
+        stmts = astroid.extract_node("""
         import logging #@
         logging.warn('%s' % '%s')  #@
         """)
@@ -25,8 +27,15 @@ class LoggingModuleDetectionTest(CheckerTestCase):
         with self.assertAddsMessages(Message('logging-not-lazy', node=stmts[1])):
             self.checker.visit_call(stmts[1])
 
+    def test_dont_crash_on_invalid_format_string(self):
+        node = astroid.parse('''
+        import logging
+        logging.error('0} - {1}'.format(1, 2))
+        ''')
+        self.walk(node)
+
     def test_detects_renamed_standard_logging_module(self):
-        stmts = test_utils.extract_node("""
+        stmts = astroid.extract_node("""
         import logging as blogging #@
         blogging.warn('%s' % '%s')  #@
         """)
@@ -37,7 +46,7 @@ class LoggingModuleDetectionTest(CheckerTestCase):
 
     @set_config(logging_modules=['logging', 'my.logging'])
     def test_nonstandard_logging_module(self):
-        stmts = test_utils.extract_node("""
+        stmts = astroid.extract_node("""
         from my import logging as blogging #@
         blogging.warn('%s' % '%s')  #@
         """)
@@ -45,7 +54,3 @@ class LoggingModuleDetectionTest(CheckerTestCase):
         self.checker.visit_import(stmts[0])
         with self.assertAddsMessages(Message('logging-not-lazy', node=stmts[1])):
             self.checker.visit_call(stmts[1])
-
-
-if __name__ == '__main__':
-    unittest.main()
