@@ -1,8 +1,21 @@
+# -*- coding: utf-8 -*-
 # Copyright (c) 2006-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2009 Charles Hebert <charles.hebert@logilab.fr>
 # Copyright (c) 2011-2014 Google, Inc.
-# Copyright (c) 2013-2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2012 Kevin Jing Qiu <kevin.jing.qiu@gmail.com>
+# Copyright (c) 2012 Anthony VEREZ <anthony.verez.external@cassidian.com>
+# Copyright (c) 2012 FELD Boris <lothiraldan@gmail.com>
+# Copyright (c) 2013-2017 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
 # Copyright (c) 2015 Florian Bruhin <me@the-compiler.org>
+# Copyright (c) 2015 Noam Yorav-Raphael <noamraph@gmail.com>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2016-2017 Derek Gustafson <degustaf@gmail.com>
 # Copyright (c) 2016 Glenn Matthews <glenn@e-dad.net>
+# Copyright (c) 2016 Glenn Matthews <glmatthe@cisco.com>
+# Copyright (c) 2017 Craig Citro <craigcitro@gmail.com>
+# Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
+# Copyright (c) 2017 Ville Skyttä <ville.skytta@iki.fi>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -28,6 +41,7 @@ import pylint.testutils as testutils
 from pylint.reporters import text
 from pylint import checkers
 from pylint.checkers.utils import check_messages
+from pylint import exceptions
 from pylint import interfaces
 import pytest
 
@@ -390,6 +404,12 @@ def test_report_output_format_aliased(linter):
     assert linter.reporter.__class__.__name__ == 'TextReporter'
 
 
+def test_set_unsupported_reporter(linter):
+    text.register(linter)
+    with pytest.raises(exceptions.InvalidReporterError):
+        linter.set_option('output-format', 'missing.module.Class')
+
+
 def test_set_option_1(linter):
     linter.set_option('disable', 'C0111,W0234')
     assert not linter.is_message_enabled('C0111')
@@ -738,3 +758,17 @@ def test_custom_should_analyze_file():
     messages = reporter.messages
     assert len(messages) == 1
     assert 'invalid syntax' in messages[0]
+
+
+def test_filename_with__init__(init_linter):
+    # This tracks a regression where a file whose name ends in __init__.py,
+    # such as flycheck__init__.py, would accidentally lead to linting the
+    # entire containing directory.
+    reporter = testutils.TestReporter()
+    linter = init_linter
+    linter.open()
+    linter.set_reporter(reporter)
+    filepath = join(INPUTDIR, 'not__init__.py')
+    linter.check([filepath])
+    messages = reporter.messages
+    assert len(messages) == 0
