@@ -1,11 +1,31 @@
+# -*- coding: utf-8 -*-
 # Copyright (c) 2006-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2009 Vincent
+# Copyright (c) 2009 Mads Kiilerich <mads@kiilerich.com>
 # Copyright (c) 2012-2014 Google, Inc.
+# Copyright (c) 2014-2017 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014-2015 Michal Nowikowski <godfryd@gmail.com>
+# Copyright (c) 2014 LCD 47 <lcd047@gmail.com>
 # Copyright (c) 2014 Brett Cannon <brett@python.org>
-# Copyright (c) 2014-2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
+# Copyright (c) 2014 Damien Nozay <damien.nozay@gmail.com>
 # Copyright (c) 2015 Aru Sahni <arusahni@gmail.com>
 # Copyright (c) 2015 Florian Bruhin <me@the-compiler.org>
-# Copyright (c) 2016 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2015 Simu Toni <simutoni@gmail.com>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2016 Łukasz Rogalski <rogalski.91@gmail.com>
+# Copyright (c) 2016 Moises Lopez <moylop260@vauxoo.com>
 # Copyright (c) 2016 Glenn Matthews <glenn@e-dad.net>
+# Copyright (c) 2016 Glenn Matthews <glmatthe@cisco.com>
+# Copyright (c) 2016 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2016 xmo-odoo <xmo-odoo@users.noreply.github.com>
+# Copyright (c) 2017 Chris Lamb <chris@chris-lamb.co.uk>
+# Copyright (c) 2017 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2017 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2017 Thomas Hisch <t.hisch@gmail.com>
+# Copyright (c) 2017 Mikhail Fesenko <proggga@gmail.com>
+# Copyright (c) 2017 Craig Citro <craigcitro@gmail.com>
+# Copyright (c) 2017 Ville Skyttä <ville.skytta@iki.fi>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -15,6 +35,7 @@ main pylint class
 """
 from __future__ import print_function
 
+import codecs
 import collections
 from inspect import cleandoc
 import os
@@ -118,9 +139,24 @@ def category_id(cid):
         return cid
     return MSG_TYPES_LONG.get(cid)
 
+def safe_decode(line, encoding, *args, **kwargs):
+    '''return decoded line from encoding or decode with default encoding'''
+    try:
+        return line.decode(encoding or sys.getdefaultencoding(), *args, **kwargs)
+    except LookupError:
+        return line.decode(sys.getdefaultencoding(), *args, **kwargs)
+
+def decoding_stream(stream, encoding, errors='strict'):
+    try:
+        reader_cls = codecs.getreader(encoding or sys.getdefaultencoding())
+    except LookupError:
+        reader_cls = codecs.getreader(sys.getdefaultencoding())
+    return reader_cls(stream, errors)
+
 
 def _decoding_readline(stream, encoding):
-    return lambda: stream.readline().decode(encoding, 'replace')
+    '''return lambda function for tokenize with safe decode'''
+    return decoding_stream(stream, encoding, errors='replace').readline
 
 
 def tokenize_module(module):
@@ -313,6 +349,7 @@ class MessagesHandlerMixIn(object):
                 return MSG_STATE_SCOPE_MODULE
         except (KeyError, TypeError):
             return MSG_STATE_SCOPE_CONFIG
+        return None
 
     def is_message_enabled(self, msg_descr, line=None, confidence=None):
         """return true if the message associated to the given message id is
@@ -454,7 +491,7 @@ class MessagesHandlerMixIn(object):
         print("Below is a list of all checkers and their features.", file=stream)
         print("", file=stream)
 
-        for checker, info in six.iteritems(by_checker):
+        for checker, info in sorted(six.iteritems(by_checker)):
             self._print_checker_doc(checker, info, stream=stream)
 
     @staticmethod
@@ -840,6 +877,10 @@ def expand_modules(files_or_modules, black_list, black_list_re):
     result = []
     errors = []
     for something in files_or_modules:
+        if os.path.basename(something) in black_list:
+            continue
+        if _basename_in_blacklist_re(os.path.basename(something), black_list_re):
+            continue
         if exists(something):
             # this is a file or a directory
             try:
@@ -881,7 +922,7 @@ def expand_modules(files_or_modules, black_list, black_list_re):
                            'basepath': filepath, 'basename': modname})
 
         has_init = (not (modname.endswith('.__init__') or modname == '__init__')
-                    and '__init__.py' in filepath)
+                    and basename(filepath) == '__init__.py')
 
         if has_init or is_namespace or is_directory:
             for subfilepath in modutils.get_module_files(dirname(filepath), black_list,
@@ -1049,7 +1090,8 @@ def _splitstrip(string, sep=','):
     ['a', 'b', 'c', '4']
     >>> _splitstrip('a')
     ['a']
-    >>>
+    >>> _splitstrip('a,\nb,\nc,')
+    ['a', 'b', 'c']
 
     :type string: str or unicode
     :param string: a csv line
@@ -1157,6 +1199,12 @@ def _ini_format(stream, options, encoding):
             print('#%s=' % optname, file=stream)
         else:
             value = _encode(value, encoding).strip()
+            if re.match(r'^([\w-]+,)+[\w-]+$', str(value)):
+                separator = '\n ' + ' ' * len(optname)
+                value = separator.join(
+                    x + ',' for x in str(value).split(','))
+                # remove trailing ',' from last element of the list
+                value = value[:-1]
             print('%s=%s' % (optname, value), file=stream)
 
 format_section = _ini_format_section
